pub type ItemVerifyingKey = VerifyingKey;Expand description
The type of a prepared verifying key. This is the key used to verify individual items.
Aliased Type
pub struct ItemVerifyingKey { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 880 bytes